@@ -5,7 +5,8 @@ import ncdistributerlib.docopt as docopt
 
 class DistributeApp(ncdistributerlib.Distributor):
     __doc__ = """
-{appname} Copyright (c) 2014 Nicholas Cole
+{appname} 
+Copyright (c) 2014 Nicholas Cole
 
 This application will package a script for distribution.
 
@@ -27,8 +28,7 @@ Options:
                           the zip archive filename.
                           [default: pyz]
     
-    -v | -vv               Verbose
-
+    -v | -vv               Verbose operation.
 
     """.format(appname=sys.argv[0])
 
