@@ -65,7 +65,7 @@ Returns (modulename, module) for each of them.
                 if include_this:
                     if self.verbose > 0:
                         for pt in M.modules[k].__path__:
-                            print(" -- including: ", pt)
+                            print(" ++ including: ", pt)
                     #print((k, M.modules[k]))
                     yield (k, M.modules[k])
                 
